@@ -1,4 +1,9 @@
+import logging
+
 from .hive import HiveOfflineStore, HiveOfflineStoreConfig
 from .hive_source import HiveOptions, HiveSource
 
 __all__ = ["HiveOptions", "HiveSource", "HiveOfflineStoreConfig", "HiveOfflineStore"]
+
+_impala_logger = logging.getLogger("impala")
+_impala_logger.setLevel(logging.WARNING)
